|
|
|
|
|
|
|
|
|
|
xen-changelog
[Xen-changelog] Use "vcpu" when referring to vcpus.
# HG changeset patch
# User cl349@xxxxxxxxxxxxxxxxxxxx
# Node ID 4490e39fc3228088939cab93bb77ba5ecbc46589
# Parent 8cba45a77249ee2da7f694b2467fb66392a6e4b1
Use "vcpu" when referring to vcpus.
Signed-off-by: Christian Limpach <Christian.Limpach@xxxxxxxxxxxx>
diff -r 8cba45a77249 -r 4490e39fc322 tools/python/xen/xend/XendDomain.py
--- a/tools/python/xen/xend/XendDomain.py Fri Sep 16 19:08:36 2005
+++ b/tools/python/xen/xend/XendDomain.py Fri Sep 16 19:11:39 2005
@@ -155,7 +155,7 @@
if not dom0:
dom0 = self.domain_unknown(0)
dom0.dom0_init_store()
- dom0.dom0_enforce_cpus()
+ dom0.dom0_enforce_vcpus()
def close(self):
pass
diff -r 8cba45a77249 -r 4490e39fc322 tools/python/xen/xend/XendRoot.py
--- a/tools/python/xen/xend/XendRoot.py Fri Sep 16 19:08:36 2005
+++ b/tools/python/xen/xend/XendRoot.py Fri Sep 16 19:11:39 2005
@@ -87,7 +87,7 @@
dom0_min_mem_default = '0'
- dom0_cpus_default = '0'
+ dom0_vcpus_default = '0'
components = {}
@@ -332,8 +332,8 @@
def get_dom0_min_mem(self):
return self.get_config_int('dom0-min-mem', self.dom0_min_mem_default)
- def get_dom0_cpus(self):
- return self.get_config_int('dom0-cpus', self.dom0_cpus_default)
+ def get_dom0_vcpus(self):
+ return self.get_config_int('dom0-cpus', self.dom0_vcpus_default)
def instance():
"""Get an instance of XendRoot.
_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog
|
<Prev in Thread] |
Current Thread |
[Next in Thread> |
- [Xen-changelog] Use "vcpu" when referring to vcpus.,
Xen patchbot -unstable <=
|
|
|
|
|
diff -r 8cba45a77249 -r 4490e39fc322 tools/python/xen/xend/XendDomainInfo.py
--- a/tools/python/xen/xend/XendDomainInfo.py Fri Sep 16 19:08:36 2005
+++ b/tools/python/xen/xend/XendDomainInfo.py Fri Sep 16 19:11:39 2005
@@ -1120,13 +1120,13 @@
# get run-time value of vcpus and update store
self.configure_vcpus(dom_get(self.domid)['vcpus'])
- def dom0_enforce_cpus(self):
+ def dom0_enforce_vcpus(self):
dom = 0
# get max number of cpus to use for dom0 from config
from xen.xend import XendRoot
xroot = XendRoot.instance()
- target = int(xroot.get_dom0_cpus())
- log.debug("number of cpus to use is %d" % (target))
+ target = int(xroot.get_dom0_vcpus())
+ log.debug("number of vcpus to use is %d" % (target))
# target = 0 means use all processors
if target > 0:
@@ -1120,13 +1120,13 @@
dom = 0
- # get max number of cpus to use for dom0 from config
+ # get max number of vcpus to use for dom0 from config
from xen.xend import XendRoot
xroot = XendRoot.instance()